==> nextcloud-25.0.12p1.tgz: nextcloud/apps/systemtags/l10n/es_GT.js <==
OC.L10N.register(
    "systemtags",
    {
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag …" : "Seleccionar etiqueta ...",
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Etiqueta del sistema %1$s eliminada",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Creaste la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Creaste la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Borraste la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Borraste la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Actualizaste la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Actualizaste la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Agregaste la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Agregaste la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "You removed system tag %2$s from %1$s" : "Eliminaste la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Eliminaste la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Tags" : "Etiquetas",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "Create a new tag" : "Crear una nueva etiqueta",
    "Name" : "Nombre",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Borrar",
    "Reset" : "Restaurar",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Please select tags to filter by" : "Por favor selecciona las etiquetas del filtro",
    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/systemtags/l10n/es_GT.js <==
OC.L10N.register(
    "systemtags",
    {
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Etiqueta del sistema %1$s eliminada",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Creaste la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Creaste la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Borraste la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Borraste la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Actualizaste la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Actualizaste la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Agregaste la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Agregaste la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "You removed system tag %2$s from %1$s" : "Eliminaste la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Eliminaste la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Files" : "Archivo",
    "Tags" : "Etiquetas",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restaurar",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "No tags found" : "No se encontraron etiquetas",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
